| Title: | Generate Analysis Results Programmes Using ARS Metadata |
|---|---|
| Description: | Analysis Results Standard (ARS), a foundational standard by CDISC (Clinical Data Interchange Standards Consortium), provides a logical data model for metadata describing all components to calculate Analysis Results. <https://www.cdisc.org/standards/foundational/analysis-results-standard> Using 'siera' package, ARS metadata is ingested (JSON or Excel format), producing programmes to generate Analysis Results Datasets (ARDs). |
| Authors: | Malan Bosman [aut, cre], Clymb Clinical [cph, fnd] |
| Maintainer: | Malan Bosman <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.5 |
| Built: | 2026-06-08 10:36:47 UTC |
| Source: | https://github.com/clymbclinical/siera |
siera comes bundled with some example ARD-producing scripts in its 'inst/script' directory. This function make them easy to access.
ARD_script_example(path = NULL)ARD_script_example(path = NULL)
path |
Name of R file. If 'NULL', the example files will be listed. |
A list of example R files (if path is NULL), or a file itself if path is used.
ARD_script_example() ARD_script_example("ARD_Out14-1-1.R")ARD_script_example() ARD_script_example("ARD_Out14-1-1.R")
siera comes bundled with some example files in its 'inst/extdata' directory. This function make them easy to access.
ARS_example(path = NULL)ARS_example(path = NULL)
path |
Name of file. If 'NULL', the example files will be listed. |
A list of example files (if path is NULL), or a file itself if path is used.
ARS_example() ARS_example("Common_Safety_Displays_cards.xlsx")ARS_example() ARS_example("Common_Safety_Displays_cards.xlsx")
Ingest ARS (Analysis Results Standard) metadata, and meta-programme R scripts that could be run as-is to produce Analysis Results Datasets when ingesting ADaM datasets
readARS( ARS_path, output_path = tempdir(), adam_path = tempdir(), spec_output = "" )readARS( ARS_path, output_path = tempdir(), adam_path = tempdir(), spec_output = "" )
ARS_path |
A file containing ARS metadata for a reporting event |
output_path |
Path to store .R ARD scripts |
adam_path |
Path to folder containing ADaM datasets, to be run in ARD program |
spec_output |
The output ID for a specific output to be run from the metadata |
R programmes generating ARDs - one for each output (or analysis from an output) specified in the ARS metadata
# path to file containing ARS metadata ARS_path <- ARS_example("Common_Safety_Displays_cards.xlsx") # output path for R programs output_dir <- tempdir() # folder containing ADaM datasets adam_folder <- tempdir() # run function, write to temp directory readARS(ARS_path, output_dir, adam_folder)# path to file containing ARS metadata ARS_path <- ARS_example("Common_Safety_Displays_cards.xlsx") # output path for R programs output_dir <- tempdir() # folder containing ADaM datasets adam_folder <- tempdir() # run function, write to temp directory readARS(ARS_path, output_dir, adam_folder)